@@ -1,12 +1,13 @@
 #!/bin/sh
 #
-# Copyright (C) 2000, 2001, 2003, 2004, 2007, 2012, 2013, 2015-2017  Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
-
-# $Id: isc-config.sh.in,v 1.17 2007/06/19 23:46:59 tbox Exp $
+#
+# See the COPYRIGHT file distributed with this work for additional
+# information regarding copyright ownership.
 
 prefix=/usr
 exec_prefix=${prefix}
@@ -64,7 +65,7 @@ while test $# -gt 0; do
 		echo_exec_prefix=true
 		;;
 	--version)
-		echo VERSION=9.12.1
+		echo VERSION=9.13.2
 		exit 0
 		;;
 	--cflags)
@@ -119,7 +120,7 @@ if test x"$echo_cflags" = x"true"; then
 		includes="-I${includedir}"
 	fi
 	if test x"$libisc" = x"true"; then
-		includes="$includes -D_REENTRANT  -I/usr/include  -D_GNU_SOURCE "
+		includes="$includes -D_REENTRANT   -D_GNU_SOURCE "
 	fi
 	echo $includes
 fi
@@ -149,7 +150,7 @@ if test x"$echo_libs" = x"true"; then
 		needothers=true
 	fi
 	if test x"$needothers" = x"true" ; then
-		libs="$libs  -ldl -lcap -ljson-c -lpthread -lm -lGeoIP  -L/usr/lib -lxml2 -lz -llzma -licui18n -licuuc -licudata -lm -ldl "
+		libs="$libs  -ldl -ljson-c -lpthread -lm -lGeoIP  -L/usr/lib -lxml2 -lz -llzma -licui18n -licuuc -licudata -lm -ldl "
 	fi
 	echo $libs
 fi
