@@ -88,23 +88,33 @@ typedef enum {
 /*
  * Options that modify how a 'fetch' is done.
  */
-#define DNS_FETCHOPT_TCP		0x0001	     /*%< Use TCP. */
-#define DNS_FETCHOPT_UNSHARED		0x0002	     /*%< See below. */
-#define DNS_FETCHOPT_RECURSIVE		0x0004	     /*%< Set RD? */
-#define DNS_FETCHOPT_NOEDNS0		0x0008	     /*%< Do not use EDNS. */
-#define DNS_FETCHOPT_FORWARDONLY	0x0010	     /*%< Only use forwarders. */
-#define DNS_FETCHOPT_NOVALIDATE		0x0020	     /*%< Disable validation. */
-#define DNS_FETCHOPT_EDNS512		0x0040	     /*%< Advertise a 512 byte
-							  UDP buffer. */
-#define DNS_FETCHOPT_WANTNSID		0x0080	     /*%< Request NSID */
-#define DNS_FETCHOPT_PREFETCH		0x0100	     /*%< Do prefetch */
-#define DNS_FETCHOPT_NOCDFLAG		0x0200	     /*%< Don't set CD flag. */
-#define DNS_FETCHOPT_NONTA		0x0400	     /*%< Ignore NTA table. */
-/* RESERVED ECS				0x0000 */
-/* RESERVED ECS				0x1000 */
-/* RESERVED ECS				0x2000 */
-/* RESERVED TCPCLIENT			0x4000 */
-#define DNS_FETCHOPT_NOCACHED		0x8000	     /*%< Force cache update. */
+#define DNS_FETCHOPT_TCP		0x00000001 /*%< Use TCP. */
+#define DNS_FETCHOPT_UNSHARED		0x00000002 /*%< See below. */
+#define DNS_FETCHOPT_RECURSIVE		0x00000004 /*%< Set RD? */
+#define DNS_FETCHOPT_NOEDNS0		0x00000008 /*%< Do not use EDNS. */
+#define DNS_FETCHOPT_FORWARDONLY	0x00000010 /*%< Only use forwarders. */
+#define DNS_FETCHOPT_NOVALIDATE		0x00000020 /*%< Disable validation. */
+#define DNS_FETCHOPT_EDNS512		0x00000040 /*%< Advertise a 512 byte
+							UDP buffer. */
+#define DNS_FETCHOPT_WANTNSID		0x00000080 /*%< Request NSID */
+#define DNS_FETCHOPT_PREFETCH		0x00000100 /*%< Do prefetch */
+#define DNS_FETCHOPT_NOCDFLAG		0x00000200 /*%< Don't set CD flag. */
+#define DNS_FETCHOPT_NONTA		0x00000400 /*%< Ignore NTA table. */
+/* RESERVED ECS				0x00000000 */
+/* RESERVED ECS				0x00001000 */
+/* RESERVED ECS				0x00002000 */
+/* RESERVED TCPCLIENT			0x00004000 */
+#define DNS_FETCHOPT_NOCACHED		0x00008000 /*%< Force cache update. */
+#define DNS_FETCHOPT_QMINIMIZE		0x00010000 /*%< Use qname
+							minimization. */
+#define DNS_FETCHOPT_QMIN_STRICT	0x00020000 /*%< Do not work around
+							servers that return
+							errors on non-empty
+							terminals. */
+#define DNS_FETCHOPT_QMIN_SKIP_IP6A	0x00040000 /*%< Skip some labels
+							when doing qname
+							minimization on
+							ip6.arpa. */
 
 /* Reserved in use by adb.c		0x00400000 */
 #define	DNS_FETCHOPT_EDNSVERSIONSET	0x00800000
@@ -134,6 +144,10 @@ typedef enum {
 #define DNS_RESOLVER_CHECKNAMES		0x01
 #define DNS_RESOLVER_CHECKNAMESFAIL	0x02
 
+#define DNS_QMIN_MAXLABELS		7
+#define DNS_QMIN_MAX_NO_DELEGATION	3
+#define DNS_MAX_LABELS			127
+
 isc_result_t
 dns_resolver_create(dns_view_t *view,
 		    isc_taskmgr_t *taskmgr,
@@ -267,7 +281,7 @@ dns_resolver_createfetch(dns_resolver_t *res, const dns_name_t *name,
 			 dns_rdatatype_t type,
 			 const dns_name_t *domain, dns_rdataset_t *nameservers,
 			 dns_forwarders_t *forwarders,
-			 const isc_sockaddr_t *client, isc_uint16_t id,
+			 const isc_sockaddr_t *client, dns_messageid_t id,
 			 unsigned int options, unsigned int depth,
 			 isc_counter_t *qc, isc_task_t *task,
 			 isc_taskaction_t action, void *arg,
